@@ -24,6 +24,10 @@ func main() {
 				rules.NewLocalsJustAttributesExampleRule(),
 				rules.NewAwsIAMRoleExampleRule(),
 				rules.NewTestingAssertionsExampleRule(),
+				rules.NewTerraformAutofixRemoveLocalRule(), // should be former than terraform_autofix_comment because this rule changes the line number
+				rules.NewTerraformAutofixCommentRule(),
+				rules.NewAwsInstanceAutofixConflictRule(), // should be later than terraform_autofix_comment because this rule adds an issue for terraform_autofix_comment
+				rules.NewTerraformRequiredProvidersRule(),
 			},
 		},
 	})
