@@ -273,6 +273,28 @@ func TestTemplateString(t *testing.T) {
 		want         cty.Value
 		wantErr      string
 	}{
+		{ // a single string interpolation that evaluates to null should fail
+			`template`,
+			map[string]cty.Value{
+				"template": cty.StringVal(`${test}`),
+			},
+			cty.ObjectVal(map[string]cty.Value{
+				"test": cty.NullVal(cty.String),
+			}),
+			cty.NilVal,
+			`<templatestring argument>:1,1-8: Template result is null; The result of the template is null, which is not a valid result for a templatestring call.`,
+		},
+		{ // a single string interpolation that evaluates to unknown should not fail
+			`template`,
+			map[string]cty.Value{
+				"template": cty.StringVal(`${test}`),
+			},
+			cty.ObjectVal(map[string]cty.Value{
+				"test": cty.UnknownVal(cty.String),
+			}),
+			cty.UnknownVal(cty.String).RefineNotNull(),
+			``,
+		},
 		{
 			`template`,
 			map[string]cty.Value{
@@ -314,7 +336,7 @@ func TestTemplateString(t *testing.T) {
 			// from somewhere else and want to avoid callers needing to deal
 			// with anything other than string results.
 			cty.NilVal,
-			`invalid template result: string required`,
+			`invalid template result: string required, but have tuple`,
 		},
 		{
 			`data.whatever.whatever["foo"].result`,
